# Server Sent Events for Starlette

Installation:

```shell
pip install sse-starlette
```

Usage:

```python
from sse_starlette import ServerSentEvent

tbd
```

Here's a more complete example, using Starlette:

```python
```

## Tests
```python
./scripts/test
```
